summaryrefslogtreecommitdiff
path: root/drivers/staging/tidspbridge/include/dspbridge/strm.h
diff options
context:
space:
mode:
authorRene Sapiens <rene.sapiens@ti.com>2010-07-09 21:23:55 -0500
committerGreg Kroah-Hartman <gregkh@suse.de>2010-07-22 10:45:34 -0700
commitb301c85803376ef997bd7802cd5f0e3e88d10ae8 (patch)
treee6da9fe16047546c1e96c06f9296a45a6ea4e28e /drivers/staging/tidspbridge/include/dspbridge/strm.h
parent0d9073abb7735dc7005a76835af055f4b6851586 (diff)
staging: ti dspbridge: Rename words with camel case.
The intention of this patch is to rename the remaining variables with camel case. Variables will be renamed avoiding camel case and Hungarian notation. The words to be renamed in this patch are: ======================================== dspAddr to dsp_address dspAdr to dsp_adr dspBaseVirt to dsp_base_virt dwDeviceContext to device_context dwDSPAddrOffset to dsp_addr_offset dwDSPAddr to dsp_addr dwErrInfo to error_info dwGPPBaseBA to gpp_base_ba dwMask to mask dwTimeout to timeout dwTimeOut to timeout dwValue to value entryNum to entry_num execFile to exec_file fFlush to flush_data FlushMemType to flush_mem_type ======================================== Signed-off-by: Rene Sapiens <rene.sapiens@ti.com> Signed-off-by: Greg Kroah-Hartman <gregkh@suse.de>
Diffstat (limited to 'drivers/staging/tidspbridge/include/dspbridge/strm.h')
-rw-r--r--drivers/staging/tidspbridge/include/dspbridge/strm.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/drivers/staging/tidspbridge/include/dspbridge/strm.h b/drivers/staging/tidspbridge/include/dspbridge/strm.h
index b85a4603d134..2ac630d8330f 100644
--- a/drivers/staging/tidspbridge/include/dspbridge/strm.h
+++ b/drivers/staging/tidspbridge/include/dspbridge/strm.h
@@ -187,16 +187,16 @@ extern int strm_get_info(struct strm_object *hStrm,
* ======== strm_idle ========
* Purpose:
* Idle a stream and optionally flush output data buffers.
* If this is an output stream and fFlush is TRUE, all data currently
* enqueued will be discarded.
* If this is an output stream and fFlush is FALSE, this function
* will block until all currently buffered data is output, or the timeout
* specified has been reached.
* After a successful call to strm_idle(), all buffers can immediately
* be reclaimed.
* Parameters:
* hStrm: Stream handle returned from strm_open().
* fFlush: If TRUE, discard output buffers.
* Returns:
* 0: Success.
* -EFAULT: Invalid hStrm.
@@ -206,7 +206,7 @@ extern int strm_get_info(struct strm_object *hStrm,
* strm_init(void) called.
* Ensures:
*/
-extern int strm_idle(struct strm_object *hStrm, bool fFlush);
+extern int strm_idle(struct strm_object *hStrm, bool flush_data);
/*
* ======== strm_init ========
@@ -187,16 +187,16 @@ extern int strm_get_info(struct strm_object *hStrm,
* Purpose:
* Idle a stream and optionally flush output data buffers.
- * If this is an output stream and fFlush is TRUE, all data currently
+ * If this is an output stream and flush_data is TRUE, all data currently
* enqueued will be discarded.
@@ -187,16 +187,16 @@ extern int strm_get_info(struct strm_object *hStrm,
* enqueued will be discarded.
- * If this is an output stream and fFlush is FALSE, this function
+ * If this is an output stream and flush_data is FALSE, this function
* will block until all currently buffered data is output, or the timeout
* specified has been reached.
@@ -187,16 +187,16 @@ extern int strm_get_info(struct strm_object *hStrm,
* Parameters:
* hStrm: Stream handle returned from strm_open().
- * fFlush: If TRUE, discard output buffers.
+ * flush_data: If TRUE, discard output buffers.
* Returns:
* 0: Success.